[−][src]Enum ruma_events::EventResult
The result of deserializing an event, which may or may not be valid.
When data is successfully deserialized and validated, this structure will contain the
deserialized value T. When deserialization succeeds, but the event is invalid for any reason,
this structure will contain an InvalidEvent. See the documentation
for InvalidEvent for more details.
Variants
T deserialized and validated successfully.
Err(InvalidEvent)T failed either deserialization or validation.
InvalidEvent contains the error message and the raw data.
Methods
impl<T: TryFromRaw> EventResult<T>[src]
pub fn into_result(self) -> Result<T, InvalidEvent>[src]
Convert EventResult<T> into the equivalent std::result::Result<T, InvalidEvent>.