Struct ruma_events::key::verification::request::RequestToDeviceEventContent [−][src]
#[non_exhaustive]pub struct RequestToDeviceEventContent { pub from_device: DeviceIdBox, pub transaction_id: String, pub methods: Vec<VerificationMethod>, pub timestamp: MilliSecondsSinceUnixEpoch, }
The payload for RequestEvent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.from_device: DeviceIdBoxExpand description
The device ID which is initiating the request.
transaction_id: StringExpand description
An opaque identifier for the verification request.
Must be unique with respect to the devices involved.
methods: Vec<VerificationMethod>Expand description
The verification methods supported by the sender.
timestamp: MilliSecondsSinceUnixEpochExpand description
The time in milliseconds for when the request was made.
If the request is in the future by more than 5 minutes or more than 10 minutes in the past, the message should be ignored by the receiver.
Implementations
impl RequestToDeviceEventContent[src]
impl RequestToDeviceEventContent[src]pub fn new(
from_device: DeviceIdBox,
transaction_id: String,
methods: Vec<VerificationMethod>,
timestamp: MilliSecondsSinceUnixEpoch
) -> Self[src]
pub fn new(
from_device: DeviceIdBox,
transaction_id: String,
methods: Vec<VerificationMethod>,
timestamp: MilliSecondsSinceUnixEpoch
) -> Self[src]Creates a new RequestToDeviceEventContent with the given device ID, transaction ID,
methods and timestamp.