Struct ruma_events::room::encryption::EncryptionEventContent [−][src]
#[non_exhaustive]pub struct EncryptionEventContent { pub algorithm: EventEncryptionAlgorithm, pub rotation_period_ms: Option<UInt>, pub rotation_period_msgs: Option<UInt>, }
The payload for EncryptionEvent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.algorithm: EventEncryptionAlgorithmThe encryption algorithm to be used to encrypt messages sent in this room.
Must be m.megolm.v1.aes-sha2.
rotation_period_ms: Option<UInt>How long the session should be used before changing it.
uint!(604800000) (a week) is the recommended default.
rotation_period_msgs: Option<UInt>How many messages should be sent before changing the session.
uint!(100) is the recommended default.
Implementations
impl EncryptionEventContent[src]
impl EncryptionEventContent[src]pub fn new(algorithm: EventEncryptionAlgorithm) -> Self[src]
pub fn new(algorithm: EventEncryptionAlgorithm) -> Self[src]Creates a new EncryptionEventContent with the given algorithm.