Enum ruma_events::room::message::MessageType [−][src]
pub enum MessageType {
Audio(AudioMessageEventContent),
Emote(EmoteMessageEventContent),
File(FileMessageEventContent),
Image(ImageMessageEventContent),
Location(LocationMessageEventContent),
Notice(NoticeMessageEventContent),
ServerNotice(ServerNoticeMessageEventContent),
Text(TextMessageEventContent),
Video(VideoMessageEventContent),
// some variants omitted
}Expand description
The content that is specific to each message type variant.
Variants
Audio(AudioMessageEventContent)An audio message.
Emote(EmoteMessageEventContent)An emote message.
File(FileMessageEventContent)A file message.
Image(ImageMessageEventContent)An image message.
Location(LocationMessageEventContent)A location message.
Notice(NoticeMessageEventContent)A notice message.
ServerNotice(ServerNoticeMessageEventContent)A server notice message.
Text(TextMessageEventContent)A text message.
Video(VideoMessageEventContent)A video message.
Implementations
impl MessageType[src]
impl MessageType[src]pub fn new(msgtype: &str, data: Map<String, JsonValue>) -> Result<Self>[src]
pub fn new(msgtype: &str, data: Map<String, JsonValue>) -> Result<Self>[src]Creates a new MessageType with the given msgtype string and data.
Prefer to use the public variants of MessageType where possible; this constructor is meant
be used for unsupported message types only and does not allow setting arbitrary data for
supported ones.