Struct ruma_events::room::message::ImageMessageEventContent[][src]

#[non_exhaustive]
pub struct ImageMessageEventContent { pub body: String, pub url: Option<MxcUri>, pub file: Option<Box<EncryptedFile>>, pub info: Option<Box<ImageInfo>>, }
The payload for an image message.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
body: String

A textual representation of the image.

This could be the alt text of the image, the filename of the image, or some kind of content description for accessibility e.g. “image attachment”.

url: Option<MxcUri>

The URL to the image.

file: Option<Box<EncryptedFile>>

Information on the encrypted image.

Required if image is encrypted.

info: Option<Box<ImageInfo>>

Metadata about the image referred to in url.

Implementations

impl ImageMessageEventContent[src]

pub fn plain(body: String, url: MxcUri, info: Option<Box<ImageInfo>>) -> Self[src]

Creates a new non-encrypted ImageMessageEventContent with the given body, url and optional extra info.

pub fn encrypted(body: String, file: EncryptedFile) -> Self[src]

Creates a new encrypted ImageMessageEventContent with the given body and encrypted file.