Struct ruma_events::room::message::MessageEventContent[][src]

#[non_exhaustive]
pub struct MessageEventContent { pub msgtype: MessageType, pub relates_to: Option<Relation>, }
The payload for MessageEvent.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
msgtype: MessageType

A key which identifies the type of message being sent.

This also holds the specific content of each message.

relates_to: Option<Relation>

Information about related messages for rich replies.

Implementations

impl MessageEventContent[src]

pub fn new(msgtype: MessageType) -> Self[src]

Create a MessageEventContent with the given MessageType.

pub fn text_plain(body: impl Into<String>) -> Self[src]

A constructor to create a plain text message.

pub fn text_html(body: impl Into<String>, html_body: impl Into<String>) -> Self[src]

A constructor to create an html message.

pub fn notice_plain(body: impl Into<String>) -> Self[src]

A constructor to create a plain text notice.

pub fn notice_html(
    body: impl Into<String>,
    html_body: impl Into<String>
) -> Self
[src]

A constructor to create an html notice.

pub fn text_reply_plain(
    reply: impl Into<String>,
    original_message: &MessageEvent
) -> Self
[src]

Creates a plain text reply to a message.

pub fn text_reply_html(
    reply: impl Into<String>,
    html_reply: impl Into<String>,
    original_message: &MessageEvent
) -> Self
[src]

Creates a html text reply to a message.

pub fn notice_reply_plain(
    reply: impl Into<String>,
    original_message: &MessageEvent
) -> Self
[src]

Creates a plain text notice reply to a message.

pub fn notice_reply_html(
    reply: impl Into<String>,
    html_reply: impl Into<String>,
    original_message: &MessageEvent
) -> Self
[src]

Creates a html text notice reply to a message.