Struct ruma_events::room::message::ServerNoticeMessageEventContent [−][src]
#[non_exhaustive]pub struct ServerNoticeMessageEventContent { pub body: String, pub server_notice_type: ServerNoticeType, pub admin_contact: Option<String>, pub limit_type: Option<LimitType>, }
The payload for a server notice message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.body: StringA human-readable description of the notice.
server_notice_type: ServerNoticeTypeThe type of notice being represented.
admin_contact: Option<String>A URI giving a contact method for the server administrator.
Required if the notice type is m.server_notice.usage_limit_reached.
limit_type: Option<LimitType>The kind of usage limit the server has exceeded.
Required if the notice type is m.server_notice.usage_limit_reached.
Implementations
impl ServerNoticeMessageEventContent[src]
impl ServerNoticeMessageEventContent[src]pub fn new(body: String, server_notice_type: ServerNoticeType) -> Self[src]
pub fn new(body: String, server_notice_type: ServerNoticeType) -> Self[src]Creates a new ServerNoticeMessageEventContent with the given body and notice type.