[][src]Struct ruma_events::room::message::VideoMessageEventContent

pub struct VideoMessageEventContent {
    pub body: String,
    pub info: Option<VideoInfo>,
    pub url: Option<String>,
    pub file: Option<EncryptedFile>,
}

The payload for a video message.

Fields

body: String

A description of the video, e.g. "Gangnam Style," or some kind of content description for accessibility, e.g. "video attachment."

info: Option<VideoInfo>

Metadata about the video clip referred to in url.

url: Option<String>

The URL to the video clip. Required if the file is unencrypted. The URL (typically MXC URI) to the video clip.

file: Option<EncryptedFile>

Required if video clip is encrypted. Information on the encrypted video clip.