Struct ruma_events::room::EncryptedFileInit[][src]

pub struct EncryptedFileInit {
    pub url: MxcUri,
    pub key: JsonWebKey,
    pub iv: String,
    pub hashes: BTreeMap<String, String>,
    pub v: String,
}
Initial set of fields of EncryptedFile.

This struct will not be updated even if additional fields are added to EncryptedFile in a new (non-breaking) release of the Matrix specification.

Fields

url: MxcUri

The URL to the file.

key: JsonWebKey

A JSON Web Key object.

iv: String

The 128-bit unique counter block used by AES-CTR, encoded as unpadded base64.

hashes: BTreeMap<String, String>

A map from an algorithm name to a hash of the ciphertext, encoded as unpadded base64. Clients should support the SHA-256 hash, which uses the key sha256.

v: String

Version of the encrypted attachments protocol. Must be v2.