Struct ruma_events::room_key::RoomKeyToDeviceEventContent [−][src]
#[non_exhaustive]pub struct RoomKeyToDeviceEventContent { pub algorithm: EventEncryptionAlgorithm, pub room_id: RoomId, pub session_id: String, pub session_key: String, }
The payload for RoomKeyEvent.
Typically encrypted as an m.room.encrypted event, then sent as a to-device event.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.algorithm: EventEncryptionAlgorithmExpand description
The encryption algorithm the key in this event is to be used with.
Must be m.megolm.v1.aes-sha2.
room_id: RoomIdExpand description
The room where the key is used.
session_id: StringExpand description
The ID of the session that the key is for.
session_key: StringExpand description
The key to be exchanged.
Implementations