[−][src]Struct ruma_events::room_key_request::RoomKeyRequestEventContent
The payload for RoomKeyRequestEvent.
Fields
action: ActionWhether this is a new key request or a cancellation of a previous request.
body: Option<RequestedKeyInfo>Information about the requested key.
Required when action is request.
requesting_device_id: DeviceIdID of the device requesting the key.
request_id: StringA random string uniquely identifying the request for a key.
If the key is requested multiple times, it should be reused. It should also reused in order to cancel a request.