Struct ruma_events::room_key_request::RoomKeyRequestToDeviceEventContent [−][src]
#[non_exhaustive]pub struct RoomKeyRequestToDeviceEventContent { pub action: Action, pub body: Option<RequestedKeyInfo>, pub requesting_device_id: DeviceIdBox, pub request_id: String, }
The payload for RoomKeyRequestEvent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: ActionExpand description
Whether this is a new key request or a cancellation of a previous request.
body: Option<RequestedKeyInfo>Expand description
Information about the requested key.
Required if action is request.
requesting_device_id: DeviceIdBoxExpand description
ID of the device requesting the key.
request_id: StringExpand description
A random string uniquely identifying the request for a key.
If the key is requested multiple times, it should be reused. It should also reused in order to cancel a request.
Implementations
impl RoomKeyRequestToDeviceEventContent[src]
impl RoomKeyRequestToDeviceEventContent[src]pub fn new(
action: Action,
body: Option<RequestedKeyInfo>,
requesting_device_id: DeviceIdBox,
request_id: String
) -> Self[src]
pub fn new(
action: Action,
body: Option<RequestedKeyInfo>,
requesting_device_id: DeviceIdBox,
request_id: String
) -> Self[src]Creates a new RoomKeyRequestToDeviceEventContent with the given action, boyd, device ID
and request ID.