Struct ruma_events::sticker::StickerEventContent [−][src]
#[non_exhaustive]pub struct StickerEventContent { pub body: String, pub info: ImageInfo, pub url: MxcUri, }
The payload for StickerEvent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct {{ .. }} syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.body: StringExpand description
A textual representation or associated description of the sticker image. This could be the alt text of the original image, or a message to accompany and further describe the sticker.
info: ImageInfoExpand description
Metadata about the image referred to in url including a thumbnail representation.
url: MxcUriExpand description
The URL to the sticker image. This must be a valid mxc:// URI.
Implementations