#[non_exhaustive]pub enum StreamCancelCode {
UnknownStream,
InvalidSubscription,
Forbidden,
LimitExceeded,
UserCancelled,
}Expand description
A machine-readable cancellation code for an event stream subscription.
Custom error codes should use the Java package naming convention.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownStream
The publisher has no active stream for the requested descriptor, or the descriptor has expired.
InvalidSubscription
The subscription request is malformed or names an invalid subscriber device.
Forbidden
The subscriber is not allowed to receive updates.
LimitExceeded
The publisher has hit an implementation limit.
UserCancelled
The subscriber no longer wants updates.
Implementations