#[non_exhaustive]pub struct StreamDescriptor {
pub device_id: OwnedDeviceId,
pub expiry_ms: Option<Duration>,
}Expand description
A descriptor advertising that a room event has a live event stream.
See MSC4471 for the proposal.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.device_id: OwnedDeviceIdThe publisher device, owned by the sender of the room event containing the descriptor.
expiry_ms: Option<Duration>The lifetime of the descriptor in milliseconds, counted from the room
event’s origin_server_ts.
Implementations
Sourceimpl StreamDescriptor
impl StreamDescriptor
Sourcepub fn new(device_id: OwnedDeviceId) -> Self
pub fn new(device_id: OwnedDeviceId) -> Self
Creates a new StreamDescriptor for the given publisher device.