[−][src]Struct ruma_events::room::message::ImageMessageEventContent
The payload for an image message.
Fields
body: StringA textual representation of the image. This could be the alt text of the image, the filename of the image, or some kind of content description for accessibility e.g. "image attachment."
info: Option<ImageInfo>Metadata about the image referred to in url.
url: Option<String>The URL to the image. Required if the file is unencrypted. The URL (typically MXC URI) to the image.
file: Option<EncryptedFile>Required if image is encrypted. Information on the encrypted image.