[][src]Struct ruma_events::room::message::ImageMessageEventContent

pub struct ImageMessageEventContent {
    pub body: String,
    pub info: Option<ImageInfo>,
    pub msgtype: MessageType,
    pub url: String,
}

The payload of an image message.

Fields

body: String

A textual representation of the image. This could be the alt text of the image, the filename of the image, or some kind of content description for accessibility e.g. "image attachment."

info: Option<ImageInfo>

Metadata about the image referred to in url.

msgtype: MessageType

The message type. Always m.image.

url: String

The URL to the image.