[−][src]Struct ruma_events::room::message::ImageMessageEventContent
The payload of an image message.
Fields
body: StringA textual representation of the image. This could be the alt text of the image, the filename of the image, or some kind of content description for accessibility e.g. "image attachment."
info: Option<ImageInfo>Metadata about the image referred to in url.
msgtype: MessageTypeThe message type. Always m.image.
url: StringThe URL to the image.