[][src]Struct ruma_events::room::message::VideoMessageEventContent

pub struct VideoMessageEventContent {
    pub body: String,
    pub info: Option<VideoInfo>,
    pub msgtype: MessageType,
    pub url: String,
}

The payload of a video message.

Fields

body: String

A description of the video, e.g. "Gangnam Style," or some kind of content description for accessibility, e.g. "video attachment."

info: Option<VideoInfo>

Metadata about the video clip referred to in url.

msgtype: MessageType

The message type. Always m.video.

url: String

The URL to the video clip.